==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/admin/messages/zh-TW/base.php <==
<?php
return array (
  '<strong>Administration</strong> menu' => '',
  '<strong>Maintenance</strong> Mode' => '',
  '<strong>Module</strong> Administration' => '',
  '<strong>Warning</strong> incomplete setup!' => '',
  'About' => '',
  'Activate' => '',
  'Add Licence Key' => '',
  'Admin' => '',
  'Administration' => '管理功能',
  'Administrative group' => '',
  'Administrators' => '',
  'Advanced' => '',
  'Advanced settings' => '',
  'Appearance' => '',
  'Approval' => '',
  'Authentication' => '',
  'Back to overview' => '',
  'Back to user overview' => '',
  'Base URL needs to begin with http:// or https://' => '',
  'Basic' => '',
  'Caching' => '',
  'Configure' => '',
  'Cronjobs' => '',
  'Deactivate' => '',
  'Default' => '',
  'Default group for administrators of this HumHub Installation' => '',
  'Default group for all newly registered users of the network' => '',
  'Delete all' => '',
  'Delete selected rows' => '',
  'Design' => '',
  'Files' => '',
  'General' => '',
  'Groups' => '',
  'Groups (Note: The Administrator group of this user can\'t be managed with your permissions)' => '',
  'Information' => '',
  'Invalid user state: {state}' => '',
  'Invite' => '',
  'Invited by' => '',
  'Logging' => '',
  'Logs' => '',
  'Mailing' => '',
  'Modules' => '',
  'No modules installed yet. Install some to enhance the functionality!' => '',
  'Notifications' => '',
  'OEmbed' => '',
  'OEmbed providers' => '',
  'Open documentation' => '',
  'Pending user registrations' => '',
  'People' => '',
  'Permissions' => '',
  'Proxy' => '',
  'Search' => '搜尋',
  'Search...' => '',
  'Self test' => '',
  'Set as default' => '',
  'Settings' => '',
  'Sign up' => '',
  'Spaces' => '空間',
  'Statistics' => '',
  'The cron job for the background jobs (queue) does not seem to work properly.' => '',
  'The cron job for the regular tasks (cron) does not seem to work properly.' => '',
  'Uninstall' => '',
  'User not found!' => '找不到此用戶',
  'Userprofiles' => '',
  'Users' => '',
);

==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/admin/messages/zh-TW/base.php <==
<?php
return array (
  '<strong>Administration</strong> menu' => '<strong>管理</strong> 選單',
  '<strong>Maintenance</strong> Mode' => '<strong>維護</strong> 模式',
  '<strong>Module</strong> Administration' => '',
  '<strong>Warning</strong> incomplete setup!' => '',
  'About' => '關於我',
  'Activate' => '啟用',
  'Add Licence Key' => '添加授權碼',
  'Admin' => '管理',
  'Administration' => '管理功能',
  'Administrative group' => '',
  'Administrators' => '管理者',
  'Advanced' => '',
  'Advanced settings' => '進階設定',
  'Appearance' => '',
  'Approval' => '',
  'Authentication' => '',
  'Back to overview' => '',
  'Back to user overview' => '',
  'Base URL needs to begin with http:// or https://' => '',
  'Basic' => '',
  'Caching' => '',
  'Configure' => '設定',
  'Cronjobs' => '',
  'Deactivate' => '',
  'Default' => '預設值',
  'Default group for administrators of this HumHub Installation' => '',
  'Default group for all newly registered users of the network' => '',
  'Delete all' => '',
  'Delete selected rows' => '',
  'Design' => '',
  'Files' => '',
  'General' => '一般資訊',
  'Groups' => '群組',
  'Groups (Note: The Administrator group of this user can\'t be managed with your permissions)' => '',
  'Information' => '',
  'Invalid user state: {state}' => '',
  'Invite by email' => '透過E-mail邀請',
  'Invite by link' => '透過連結邀請',
  'Invited by' => '',
  'Logging' => '',
  'Logs' => '',
  'Mailing' => '',
  'Modules' => '模組設定',
  'No modules installed yet. Install some to enhance the functionality!' => '',
  'Notifications' => '通知',
  'OEmbed' => '',
  'OEmbed providers' => '',
  'Open documentation' => '',
  'Pending user registrations' => '',
  'People' => '人物',
  'Permissions' => '',
  'Proxy' => '',
  'Search' => '搜尋',
  'Search...' => '搜尋...',
  'Self test' => '',
  'Set as default' => '',
  'Settings' => '设置',
  'Sign up' => '',
  'Spaces' => 'Space',
  'Statistics' => '',
  'The cron job for the background jobs (queue) does not seem to work properly.' => '',
  'The cron job for the regular tasks (cron) does not seem to work properly.' => '',
  'Uninstall' => '',
  'User not found!' => '找不到此用戶',
  'Userprofiles' => '',
  'Users' => '用戶',
);
